==> Broambox-0.01.0.zip: Broambox.h <==
class Broambox {
public:
	HWND hEditWnd;
	HWND hSlit;
	WNDPROC wpEditProc;
	COLORREF textColor;

	Broambox(HINSTANCE, HWND);
	bool CreateBroambox();
	void DestroyBroambox();
	void PaintBroambox(HDC, LPRECT);
	void SizeBroambox();
	void MoveBroambox(WINDOWPOS*);

	void ReadSettings();
	void ReplaceFont();

	void ShowWindow();
	void ShowWindowAt(int x, int y);
	void HideWindow();

	void EnterSlit();
	void LeaveSlit();
	void UpdateSlit();
	bool InSlit() { return (inSlit && (hSlit != NULL)); }
	void ToggleSlitAutoHide(bool);

	void ToggleInSlit() {
		if(!hSlit) return;
		if(InSlit())
			LeaveSlit();
		else
			EnterSlit();
	}

	void Execute();
	void HistoryPrev();
	void HistoryNext();
	void ResetHistoryIndex() { historyIndex = 0; }

	LRESULT LButtonDown(HWND, UINT, WPARAM, LPARAM);
	LRESULT RButtonDown(HWND, UINT, WPARAM, LPARAM);

	LPCSTR GetAppName() { return "Broambox"; }
	LPCSTR GetAppAuthor() { return "Brian \"Tres`ni\" Hartvigsen"; }
	LPCSTR GetAppEmail() { return "tresni@crackmonkey.us"; }
	LPCSTR GetAppLink()  { return "http://www.crackmonkey.us"; }
	LPCSTR GetAppVersion() { return "0.01.0"; }
	LPCSTR GetAppRelease() { return "NONE"; }

private:
	HINSTANCE hMainInst;

	HWND hBB4Win;
	HFONT hEditFont;

	bool inSlit;
	bool tempSlit;
	bool isSlitAutoHide;

	StyleItem *mainStyle;
	StyleItem *editStyle;

	Menu *mainMenu;

	COLORREF mainBackColor, mainBackColorTo;
	COLORREF editBackColor, editBackColorTo;
	COLORREF borderColor;
	bool no8Ball;
	bool noWho;
	int x, y, width, height, bevel, border;
	char fontFace[MAX_PATH];
	int fontHeight;

	int historyIndex;
	int historyCount;
	char history[10][MAX_LINE_LENGTH];
};

==> Broambox-0.01.1.zip: Broambox.h <==
class Broambox {
public:
	HWND hEditWnd;
	HWND hSlit;
	WNDPROC wpEditProc;
	COLORREF textColor;

	Broambox(HINSTANCE, HWND);
	bool CreateBroambox();
	void DestroyBroambox();
	void PaintBroambox(HDC, LPRECT);
	void SizeBroambox();
	void MoveBroambox(WINDOWPOS*);

	void ReadSettings();
	void ReplaceFont();

	void ShowWindow();
	void ShowWindowAt(int x, int y);
	void HideWindow();

	void EnterSlit();
	void LeaveSlit();
	void UpdateSlit();
	bool InSlit() { return ( inSlit && (hSlit != NULL) ); }
	void ToggleSlitAutoHide(bool);

	void ToggleInSlit() {
		if(hSlit == NULL) return;
		if( InSlit() )
			LeaveSlit();
		else
			EnterSlit();
	}

	void Execute();
	void HistoryPrev();
	void HistoryNext();
	void ResetHistoryIndex() { historyIndex = 0; }

	LRESULT LButtonDown(HWND, UINT, WPARAM, LPARAM);
	LRESULT RButtonDown(HWND, UINT, WPARAM, LPARAM);

	LPCSTR GetAppName() { return "Broambox"; }
	LPCSTR GetAppAuthor() { return "Brian \"Tres`ni\" Hartvigsen"; }
	LPCSTR GetAppEmail() { return "tresni@crackmonkey.us"; }
	LPCSTR GetAppLink()  { return "http://www.crackmonkey.us"; }
	LPCSTR GetAppVersion() { return "0.01.1"; }
	LPCSTR GetAppRelease() { return "01 NOV 2003"; }

private:
	HINSTANCE hMainInst;

	HWND hBB4Win;
	HFONT hEditFont;

	bool inSlit;
	bool tempSlit;
	bool isSlitAutoHide;

	StyleItem *mainStyle;
	StyleItem *editStyle;

	Menu *mainMenu;

	COLORREF mainBackColor, mainBackColorTo;
	COLORREF editBackColor, editBackColorTo;
	COLORREF borderColor;
	bool no8Ball;
	bool noWho;
	int x, y, width, height, bevel, border;
	char fontFace[MAX_PATH];
	int fontHeight;

	int historyIndex;
	int historyCount;
	char history[10][MAX_LINE_LENGTH];
};
